import * as React from 'react';
export declare type FieldValue = any;
export declare type Validate = (data: FieldValue) => string | boolean;
export declare type NumberOrString = number | string;
declare type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;
export interface DataType {
    [key: string]: FieldValue;
}
export declare type OnSubmit<Data extends DataType> = (data: Data, e: React.SyntheticEvent) => void;
export interface Props<Data> {
    mode?: 'onSubmit' | 'onBlur' | 'onChange';
    defaultValues?: {
        [key: string]: any;
    };
    nativeValidation?: boolean;
    validationFields?: (keyof Data)[];
    validationSchema?: any;
    submitFocusError?: boolean;
}
export interface MutationWatcher {
    disconnect: () => void;
    observe?: any;
}
export declare type Ref = any;
export interface RegisterInput {
    ref?: Ref;
    required?: boolean | string;
    min?: NumberOrString | {
        value: NumberOrString;
        message: string;
    };
    max?: NumberOrString | {
        value: NumberOrString;
        message: string;
    };
    maxLength?: number | {
        value: number;
        message: string;
    };
    minLength?: number | {
        value: number;
        message: string;
    };
    pattern?: RegExp | {
        value: RegExp;
        message: string;
    };
    validate?: Validate | {
        [key: string]: Validate;
    } | {
        value: Validate | {
            [key: string]: Validate;
        };
        message: string;
    } | undefined;
}
export interface Field extends RegisterInput {
    ref: Ref;
    watch?: boolean;
    mutationWatcher?: MutationWatcher;
    options?: {
        ref: Ref;
        mutationWatcher?: MutationWatcher;
    }[];
}
export declare type FieldsObject<Data extends DataType> = {
    [Key in keyof Data]?: Field;
};
export interface Error {
    ref: Ref;
    message?: string;
    type?: string;
    isManual?: boolean;
}
export declare type ErrorMessages<Data extends DataType> = {
    [Key in keyof Data]?: Error;
};
export interface SubmitPromiseResult<Data extends DataType> {
    errors: ErrorMessages<Data>;
    values: Data;
}
export declare type VoidFunction = () => void;
export interface FormProps<Data extends DataType = DataType> {
    children: JSX.Element[] | JSX.Element;
    register?: (refOrValidateRule: RegisterInput | Ref, validateRule?: RegisterInput) => any;
    handleSubmit?: (callback: (data: any, e: React.SyntheticEvent) => void) => (e: React.SyntheticEvent) => Promise<void>;
    watch?: Function;
    unSubscribe?: () => void;
    reset?: () => void;
    setError?: Function;
    setValue?: Function;
    triggerValidation?: Function;
    getValues?: () => DataType;
    errors?: DataType;
    formState?: {
        dirty: boolean;
        isSubmitted: boolean;
        submitCount: number;
        touched: string[] | {}[];
        isSubmitting: boolean;
        isValid: boolean;
    };
}
export declare type FormContextValues = Required<Omit<FormProps, 'children'>>;
export {};
